IsAdmin

Trait IsAdmin 

pub trait IsAdmin: HasGeometry + HasProperties {
    // Required method
    fn name(&self) -> &str;
}
A trait for types that are an admin and have a [Geometry].

Helps abstract away this property so the helper methods can be generalized.

Required Methods

fn name(&self) -> &str

Get the name of the IsAdmin.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors